# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.app_connected_github_vcs_config import AppConnectedGithubVCSConfig

class TestAppConnectedGithubVCSConfig(unittest.TestCase):
    """AppConnectedGithubVCSConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppConnectedGithubVCSConfig:
        """Test AppConnectedGithubVCSConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppConnectedGithubVCSConfig`
        """
        model = AppConnectedGithubVCSConfig()
        if include_optional:
            return AppConnectedGithubVCSConfig(
                branch = '',
                component_config_id = '',
                component_config_type = '',
                created_at = '',
                created_by_id = '',
                directory = '',
                id = '',
                repo = '',
                repo_name = '',
                repo_owner = '',
                updated_at = '',
                vcs_connection = nuon.models.app/vcs_connection.app.VCSConnection(
                    created_at = '', 
                    created_by_id = '', 
                    github_install_id = '', 
                    id = '', 
                    updated_at = '', 
                    vcs_connection_commit = [
                        nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                            author_email = '', 
                            author_name = '', 
                            component_config_connection_id = '', 
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            message = '', 
                            sha = '', 
                            updated_at = '', )
                        ], ),
                vcs_connection_id = ''
            )
        else:
            return AppConnectedGithubVCSConfig(
        )
        """

    def testAppConnectedGithubVCSConfig(self):
        """Test AppConnectedGithubVCSConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.132
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_installer import AppInstaller

class TestAppInstaller(unittest.TestCase):
    """AppInstaller unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppInstaller:
        """Test AppInstaller
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppInstaller`
        """
        model = AppInstaller()
        if include_optional:
            return AppInstaller(
                apps = [
                    nuon.models.app/app.app.App(
                        cloud_platform = 'aws', 
                        created_at = '', 
                        created_by = nuon.models.app/user_token.app.UserToken(
                            created_at = '', 
                            created_by_id = '', 
                            email = '', 
                            expires_at = '', 
                            id = '', 
                            issued_at = '', 
                            issuer = '', 
                            subject = '', 
                            token_type = 'auth0', 
                            updated_at = '', ), 
                        created_by_id = '', 
                        description = '', 
                        id = '', 
                        input_config = null, 
                        name = '', 
                        org_id = '', 
                        runner_config = nuon.models.app/app_runner_config.app.AppRunnerConfig(
                            app_id = '', 
                            app_runner_type = 'aws-ecs', 
                            created_at = '', 
                            created_by_id = '', 
                            env_vars = {
                                'key' : ''
                                }, 
                            id = '', 
                            org_id = '', 
                            updated_at = '', ), 
                        sandbox_config = nuon.models.app/app_sandbox_config.app.AppSandboxConfig(
                            app_id = '', 
                            artifacts = nuon.models.app_app_sandbox_config_artifacts.app_AppSandboxConfig_artifacts(
                                cloudformation_stack_template = '', 
                                deprovision_policy = '', 
                                provision_policy = '', 
                                trust_policy = '', ), 
                            connected_github_vcs_config = nuon.models.app/connected_github_vcs_config.app.ConnectedGithubVCSConfig(
                                branch = '', 
                                component_config_id = '', 
                                component_config_type = '', 
                                created_at = '', 
                                created_by_id = '', 
                                directory = '', 
                                id = '', 
                                repo = '', 
                                repo_name = '', 
                                repo_owner = '', 
                                updated_at = '', 
                                vcs_connection = nuon.models.app/vcs_connection.app.VCSConnection(
                                    created_at = '', 
                                    created_by_id = '', 
                                    github_install_id = '', 
                                    id = '', 
                                    updated_at = '', 
                                    vcs_connection_commit = [
                                        nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                                            author_email = '', 
                                            author_name = '', 
                                            component_config_connection_id = '', 
                                            created_at = '', 
                                            created_by_id = '', 
                                            id = '', 
                                            message = '', 
                                            sha = '', 
                                            updated_at = '', )
                                        ], ), 
                                vcs_connection_id = '', ), 
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            org_id = '', 
                            public_git_vcs_config = nuon.models.app/public_git_vcs_config.app.PublicGitVCSConfig(
                                branch = '', 
                                component_config_id = '', 
                                component_config_type = '', 
                                created_at = '', 
                                created_by_id = '', 
                                directory = '', 
                                id = '', 
                                repo = '', 
                                updated_at = '', ), 
                            sandbox_release = nuon.models.app/sandbox_release.app.SandboxRelease(
                                created_at = '', 
                                created_by_id = '', 
                                deprovision_policy_url = '', 
                                id = '', 
                                one_click_role_template_url = '', 
                                provision_policy_url = '', 
                                trust_policy_url = '', 
                                updated_at = '', 
                                version = '', ), 
                            sandbox_release_id = '', 
                            terraform_version = '', 
                            updated_at = '', 
                            variables = {
                                'key' : ''
                                }, ), 
                        status = '', 
                        status_description = '', 
                        updated_at = '', )
                    ],
                created_at = '',
                created_by = nuon.models.app/user_token.app.UserToken(
                    created_at = '', 
                    created_by_id = '', 
                    email = '', 
                    expires_at = '', 
                    id = '', 
                    issued_at = '', 
                    issuer = '', 
                    subject = '', 
                    token_type = 'auth0', 
                    updated_at = '', ),
                created_by_id = '',
                id = '',
                metadata = nuon.models.app/installer_metadata.app.InstallerMetadata(
                    community_url = '', 
                    copyright_markdown = '', 
                    created_at = '', 
                    created_by = nuon.models.app/user_token.app.UserToken(
                        created_at = '', 
                        created_by_id = '', 
                        email = '', 
                        expires_at = '', 
                        id = '', 
                        issued_at = '', 
                        issuer = '', 
                        subject = '', 
                        token_type = 'auth0', 
                        updated_at = '', ), 
                    created_by_id = '', 
                    demo_url = '', 
                    description = '', 
                    documentation_url = '', 
                    favicon_url = '', 
                    footer_markdown = '', 
                    formatted_demo_url = '', 
                    github_url = '', 
                    homepage_url = '', 
                    id = '', 
                    installer_id = '', 
                    logo_url = '', 
                    name = '', 
                    post_install_markdown = '', 
                    updated_at = '', ),
                org_id = '',
                type = 'self_hosted',
                updated_at = ''
            )
        else:
            return AppInstaller(
        )
        """

    def testAppInstaller(self):
        """Test AppInstaller"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.106
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_org_invite_status import AppOrgInviteStatus

class TestAppOrgInviteStatus(unittest.TestCase):
    """AppOrgInviteStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAppOrgInviteStatus(self):
        """Test AppOrgInviteStatus"""
        # inst = AppOrgInviteStatus()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.general_api import GeneralApi


class TestGeneralApi(unittest.TestCase):
    """GeneralApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GeneralApi()

    def tearDown(self) -> None:
        pass

    def test_get_cli_config(self) -> None:
        """Test case for get_cli_config

        Get config for cli
        """
        pass

    def test_get_current_user(self) -> None:
        """Test case for get_current_user

        Get current user
        """
        pass

    def test_publish_metrics(self) -> None:
        """Test case for publish_metrics

        Publish a metric from different Nuon clients for telemetry purposes.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.components_api import ComponentsApi


class TestComponentsApi(unittest.TestCase):
    """ComponentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ComponentsApi()

    def tearDown(self) -> None:
        pass

    def test_create_component(self) -> None:
        """Test case for create_component

        create a component
        """
        pass

    def test_create_component_build(self) -> None:
        """Test case for create_component_build

        create component build
        """
        pass

    def test_create_docker_build_component_config(self) -> None:
        """Test case for create_docker_build_component_config

        create a docker build component config
        """
        pass

    def test_create_external_image_component_config(self) -> None:
        """Test case for create_external_image_component_config

        create an external image component config
        """
        pass

    def test_create_helm_component_config(self) -> None:
        """Test case for create_helm_component_config

        create a helm component config
        """
        pass

    def test_create_job_component_config(self) -> None:
        """Test case for create_job_component_config

        create a job component config
        """
        pass

    def test_create_terraform_module_component_config(self) -> None:
        """Test case for create_terraform_module_component_config

        create a terraform component config
        """
        pass

    def test_delete_component(self) -> None:
        """Test case for delete_component

        delete a component
        """
        pass

    def test_get_app_components(self) -> None:
        """Test case for get_app_components

        get all components for an app
        """
        pass

    def test_get_build(self) -> None:
        """Test case for get_build

        get a build
        """
        pass

    def test_get_component(self) -> None:
        """Test case for get_component

        get a component
        """
        pass

    def test_get_component_build(self) -> None:
        """Test case for get_component_build

        get a build for a component
        """
        pass

    def test_get_component_build_logs(self) -> None:
        """Test case for get_component_build_logs

        get component build logs
        """
        pass

    def test_get_component_build_plan(self) -> None:
        """Test case for get_component_build_plan

        get component build plan
        """
        pass

    def test_get_component_builds(self) -> None:
        """Test case for get_component_builds

        get all builds for a component
        """
        pass

    def test_get_component_configs(self) -> None:
        """Test case for get_component_configs

        get all configs for a component
        """
        pass

    def test_get_component_latest_build(self) -> None:
        """Test case for get_component_latest_build

        get latest build for a component
        """
        pass

    def test_get_component_latest_config(self) -> None:
        """Test case for get_component_latest_config

        get latest config for a component
        """
        pass

    def test_get_org_components(self) -> None:
        """Test case for get_org_components

        get all components for an org
        """
        pass

    def test_update_component(self) -> None:
        """Test case for update_component

        update a component
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.182
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from nuon.models.app_aws_account import AppAWSAccount
from nuon.models.app_awsecr_image_config import AppAWSECRImageConfig
from nuon.models.app_account import AppAccount
from nuon.models.app_account_type import AppAccountType
from nuon.models.app_app import AppApp
from nuon.models.app_app_aws_delegation_config import AppAppAWSDelegationConfig
from nuon.models.app_app_config import AppAppConfig
from nuon.models.app_app_config_fmt import AppAppConfigFmt
from nuon.models.app_app_config_status import AppAppConfigStatus
from nuon.models.app_app_input import AppAppInput
from nuon.models.app_app_input_config import AppAppInputConfig
from nuon.models.app_app_input_group import AppAppInputGroup
from nuon.models.app_app_runner_config import AppAppRunnerConfig
from nuon.models.app_app_runner_type import AppAppRunnerType
from nuon.models.app_app_sandbox_config import AppAppSandboxConfig
from nuon.models.app_app_sandbox_config_artifacts import AppAppSandboxConfigArtifacts
from nuon.models.app_app_secret import AppAppSecret
from nuon.models.app_azure_account import AppAzureAccount
from nuon.models.app_cloud_platform import AppCloudPlatform
from nuon.models.app_cloud_platform_region import AppCloudPlatformRegion
from nuon.models.app_component import AppComponent
from nuon.models.app_component_build import AppComponentBuild
from nuon.models.app_component_config_connection import AppComponentConfigConnection
from nuon.models.app_component_release import AppComponentRelease
from nuon.models.app_component_release_step import AppComponentReleaseStep
from nuon.models.app_connected_github_vcs_config import AppConnectedGithubVCSConfig
from nuon.models.app_docker_build_component_config import AppDockerBuildComponentConfig
from nuon.models.app_external_image_component_config import AppExternalImageComponentConfig
from nuon.models.app_helm_component_config import AppHelmComponentConfig
from nuon.models.app_install import AppInstall
from nuon.models.app_install_component import AppInstallComponent
from nuon.models.app_install_deploy import AppInstallDeploy
from nuon.models.app_install_deploy_type import AppInstallDeployType
from nuon.models.app_install_event import AppInstallEvent
from nuon.models.app_install_inputs import AppInstallInputs
from nuon.models.app_install_sandbox_run import AppInstallSandboxRun
from nuon.models.app_installer import AppInstaller
from nuon.models.app_installer_metadata import AppInstallerMetadata
from nuon.models.app_installer_type import AppInstallerType
from nuon.models.app_job_component_config import AppJobComponentConfig
from nuon.models.app_notifications_config import AppNotificationsConfig
from nuon.models.app_operation_status import AppOperationStatus
from nuon.models.app_org import AppOrg
from nuon.models.app_org_health_check import AppOrgHealthCheck
from nuon.models.app_org_health_check_status import AppOrgHealthCheckStatus
from nuon.models.app_org_invite import AppOrgInvite
from nuon.models.app_org_invite_status import AppOrgInviteStatus
from nuon.models.app_policy import AppPolicy
from nuon.models.app_policy_name import AppPolicyName
from nuon.models.app_public_git_vcs_config import AppPublicGitVCSConfig
from nuon.models.app_role import AppRole
from nuon.models.app_role_type import AppRoleType
from nuon.models.app_sandbox_run_type import AppSandboxRunType
from nuon.models.app_terraform_module_component_config import AppTerraformModuleComponentConfig
from nuon.models.app_vcs_connection import AppVCSConnection
from nuon.models.app_vcs_connection_commit import AppVCSConnectionCommit
from nuon.models.metrics_decr import MetricsDecr
from nuon.models.metrics_event import MetricsEvent
from nuon.models.metrics_incr import MetricsIncr
from nuon.models.metrics_timing import MetricsTiming
from nuon.models.permissions_permission import PermissionsPermission
from nuon.models.planv1_plan import Planv1Plan
from nuon.models.service_app_config_template import ServiceAppConfigTemplate
from nuon.models.service_app_config_template_type import ServiceAppConfigTemplateType
from nuon.models.service_app_group_request import ServiceAppGroupRequest
from nuon.models.service_app_input_request import ServiceAppInputRequest
from nuon.models.service_aws_ecr_image_config_request import ServiceAwsECRImageConfigRequest
from nuon.models.service_cli_config import ServiceCLIConfig
from nuon.models.service_connected_github_vcs_config_request import ServiceConnectedGithubVCSConfigRequest
from nuon.models.service_connected_github_vcs_sandbox_config_request import ServiceConnectedGithubVCSSandboxConfigRequest
from nuon.models.service_create_app_config_request import ServiceCreateAppConfigRequest
from nuon.models.service_create_app_input_config_request import ServiceCreateAppInputConfigRequest
from nuon.models.service_create_app_request import ServiceCreateAppRequest
from nuon.models.service_create_app_runner_config_request import ServiceCreateAppRunnerConfigRequest
from nuon.models.service_create_app_sandbox_config_request import ServiceCreateAppSandboxConfigRequest
from nuon.models.service_create_app_secret_request import ServiceCreateAppSecretRequest
from nuon.models.service_create_component_build_request import ServiceCreateComponentBuildRequest
from nuon.models.service_create_component_release_request import ServiceCreateComponentReleaseRequest
from nuon.models.service_create_component_release_request_strategy import ServiceCreateComponentReleaseRequestStrategy
from nuon.models.service_create_component_request import ServiceCreateComponentRequest
from nuon.models.service_create_connection_callback_request import ServiceCreateConnectionCallbackRequest
from nuon.models.service_create_connection_request import ServiceCreateConnectionRequest
from nuon.models.service_create_docker_build_component_config_request import ServiceCreateDockerBuildComponentConfigRequest
from nuon.models.service_create_external_image_component_config_request import ServiceCreateExternalImageComponentConfigRequest
from nuon.models.service_create_helm_component_config_request import ServiceCreateHelmComponentConfigRequest
from nuon.models.service_create_install_deploy_request import ServiceCreateInstallDeployRequest
from nuon.models.service_create_install_inputs_request import ServiceCreateInstallInputsRequest
from nuon.models.service_create_install_request import ServiceCreateInstallRequest
from nuon.models.service_create_install_request_aws_account import ServiceCreateInstallRequestAwsAccount
from nuon.models.service_create_install_request_azure_account import ServiceCreateInstallRequestAzureAccount
from nuon.models.service_create_installer_request import ServiceCreateInstallerRequest
from nuon.models.service_create_installer_request_metadata import ServiceCreateInstallerRequestMetadata
from nuon.models.service_create_job_component_config_request import ServiceCreateJobComponentConfigRequest
from nuon.models.service_create_org_invite_request import ServiceCreateOrgInviteRequest
from nuon.models.service_create_org_request import ServiceCreateOrgRequest
from nuon.models.service_create_org_user_request import ServiceCreateOrgUserRequest
from nuon.models.service_create_terraform_module_component_config_request import ServiceCreateTerraformModuleComponentConfigRequest
from nuon.models.service_public_git_vcs_config_request import ServicePublicGitVCSConfigRequest
from nuon.models.service_public_git_vcs_sandbox_config_request import ServicePublicGitVCSSandboxConfigRequest
from nuon.models.service_publish_metric_input import ServicePublishMetricInput
from nuon.models.service_rendered_installer import ServiceRenderedInstaller
from nuon.models.service_repository import ServiceRepository
from nuon.models.service_update_app_request import ServiceUpdateAppRequest
from nuon.models.service_update_component_request import ServiceUpdateComponentRequest
from nuon.models.service_update_install_request import ServiceUpdateInstallRequest
from nuon.models.service_update_installer_request import ServiceUpdateInstallerRequest
from nuon.models.service_update_installer_request_metadata import ServiceUpdateInstallerRequestMetadata
from nuon.models.service_update_org_request import ServiceUpdateOrgRequest
from nuon.models.statsd_event import StatsdEvent
from nuon.models.statsd_event_alert_type import StatsdEventAlertType
from nuon.models.statsd_event_priority import StatsdEventPriority
from nuon.models.stderr_err_response import StderrErrResponse
